@@ -7,6 +7,7 @@ pub struct Config {
     pub imgur: ConfigImgur,
     pub notification: ConfigNotification,
     pub clipboard: ConfigClipboard,
+    pub discord_webhook: ConfigDiscordWebhook,
 }
 
 #[derive(Debug, Deserialize)]
@@ -23,3 +24,9 @@ pub struct ConfigNotification {
 pub struct ConfigClipboard {
     pub enabled: bool,
 }
+
+#[derive(Debug, Deserialize)]
+pub struct ConfigDiscordWebhook {
+    pub enabled: bool,
+    pub uri: String,
+}
